from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SmodeCls:
	"""Smode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("smode", core, parent)

	def set(self, search_mode: enums.SearchMode) -> None:
		"""SCPI: [SENSe]:ADJust:CONFigure:SMODe \n
		Snippet: driver.sense.adjust.configure.smode.set(search_mode = enums.SearchMode.FAST) \n
		Determines the search mode for the automatic measurement performed to determine the optimal measurement configuration. \n
			:param search_mode: FAST | POPTimzed FAST The measurement is optimized for speed. POPTimzed The measurement is optimized to analyze pulse signals adequately.
		"""
		param = Conversions.enum_scalar_to_str(search_mode, enums.SearchMode)
		self._core.io.write(f'SENSe:ADJust:CONFigure:SMODe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SearchMode:
		"""SCPI: [SENSe]:ADJust:CONFigure:SMODe \n
		Snippet: value: enums.SearchMode = driver.sense.adjust.configure.smode.get() \n
		Determines the search mode for the automatic measurement performed to determine the optimal measurement configuration. \n
			:return: search_mode: FAST | POPTimzed FAST The measurement is optimized for speed. POPTimzed The measurement is optimized to analyze pulse signals adequately."""
		response = self._core.io.query_str(f'SENSe:ADJust:CONFigure:SMODe?')
		return Conversions.str_to_scalar_enum(response, enums.SearchMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CestimationCls:
	"""Cestimation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cestimation", core, parent)

	def set(self, type_py: enums.ChannelEstUl) -> None:
		"""SCPI: [SENSe][:LTE]:UL:DEMod:CESTimation \n
		Snippet: driver.applications.k10Xlte.sense.lte.uplink.demod.cestimation.set(type_py = enums.ChannelEstUl.PIL) \n
		This command selects the channel estimation type. \n
			:param type_py: PIL Pilot only PILP Pilot and payload
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.ChannelEstUl)
		self._core.io.write(f'SENSe:LTE:UL:DEMod:CESTimation {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ChannelEstUl:
		"""SCPI: [SENSe][:LTE]:UL:DEMod:CESTimation \n
		Snippet: value: enums.ChannelEstUl = driver.applications.k10Xlte.sense.lte.uplink.demod.cestimation.get() \n
		This command selects the channel estimation type. \n
			:return: type_py: PIL Pilot only PILP Pilot and payload"""
		response = self._core.io.query_str(f'SENSe:LTE:UL:DEMod:CESTimation?')
		return Conversions.str_to_scalar_enum(response, enums.ChannelEstUl)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HfOffsetCls:
	"""HfOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hfOffset", core, parent)

	def set(self, half_frame: enums.HalfFrame, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:SSBLock:HFOFfset \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.ssBlock.hfOffset.set(half_frame = enums.HalfFrame.ONE, carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the half frame that contains the synchronization signal.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a SSB periodicity > 5 ms (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.SsBlock.BsPeriod.set) . \n
			:param half_frame: ZERO SSB in first half frame. ONE SSB in second half frame.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.enum_scalar_to_str(half_frame, enums.HalfFrame)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:SSBLock:HFOFfset {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.HalfFrame:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:SSBLock:HFOFfset \n
		Snippet: value: enums.HalfFrame = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.ssBlock.hfOffset.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the half frame that contains the synchronization signal.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a SSB periodicity > 5 ms (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.SsBlock.BsPeriod.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: half_frame: ZERO SSB in first half frame. ONE SSB in second half frame."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:SSBLock:HFOFfset?')
		return Conversions.str_to_scalar_enum(response, enums.HalfFrame)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OvershootCls:
	"""Overshoot commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("overshoot", core, parent)

	def set(self, state: bool, scaling: enums.FrequencyScaling = None, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:CHRDetection:TABLe:FREQuency:OVERshoot \n
		Snippet: driver.applications.k60Transient.calculate.chrDetection.table.frequency.overshoot.set(state = False, scaling = enums.FrequencyScaling.GHZ, window = repcap.Window.Default) \n
		No command help available \n
			:param state: 1..n
			:param scaling: GHZ | MHZ | KHZ | HZ
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('state', state, DataType.Boolean), ArgSingle('scaling', scaling, DataType.Enum, enums.FrequencyScaling, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:CHRDetection:TABLe:FREQuency:OVERshoot {param}'.rstrip())

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:CHRDetection:TABLe:FREQuency:OVERshoot \n
		Snippet: value: bool = driver.applications.k60Transient.calculate.chrDetection.table.frequency.overshoot.get(window = repcap.Window.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:CHRDetection:TABLe:FREQuency:OVERshoot?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandwidthCls:
	"""Bandwidth commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bandwidth", core, parent)

	def set(self, bandwidth: float, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:STRack:BWIDth \n
		Snippet: driver.calculate.marker.function.strack.bandwidth.set(bandwidth = 1.0, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command defines the bandwidth around the center frequency that is included in the signal tracking process. Note that
		you have to turn on signal tracking before you can use the command. \n
			:param bandwidth: Range: 10 Hz to Max span, Unit: Hz
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:STRack:BWIDth {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:STRack:BWIDth \n
		Snippet: value: float = driver.calculate.marker.function.strack.bandwidth.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command defines the bandwidth around the center frequency that is included in the signal tracking process. Note that
		you have to turn on signal tracking before you can use the command. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: bandwidth: Range: 10 Hz to Max span, Unit: Hz"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:STRack:BWIDth?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RpaCls:
	"""Rpa commands group definition. 9 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rpa", core, parent)

	@property
	def afrequency(self):
		"""afrequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_afrequency'):
			from .Afrequency import AfrequencyCls
			self._afrequency = AfrequencyCls(self._core, self._cmd_group)
		return self._afrequency

	@property
	def kzero(self):
		"""kzero commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_kzero'):
			from .Kzero import KzeroCls
			self._kzero = KzeroCls(self._core, self._cmd_group)
		return self._kzero

	@property
	def rtcf(self):
		"""rtcf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rtcf'):
			from .Rtcf import RtcfCls
			self._rtcf = RtcfCls(self._core, self._cmd_group)
		return self._rtcf

	@property
	def tbOffset(self):
		"""tbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tbOffset'):
			from .TbOffset import TbOffsetCls
			self._tbOffset = TbOffsetCls(self._core, self._cmd_group)
		return self._tbOffset

	def clone(self) -> 'RpaCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RpaCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UaChannelCls:
	"""UaChannel commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uaChannel", core, parent)

	def set(self, bandwidth: float) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:BWIDth:UACHannel \n
		Snippet: driver.sense.power.achannel.bandwidth.uaChannel.set(bandwidth = 1.0) \n
		This command defines the channel bandwidth of the upper adjacent channel in asymmetrical configurations. The adjacent
		channel is the first pair of channels next to the transmission channels. To configure the bandwidth for the lower
		adjacent channel, use the [SENSe:]POWer:ACHannel:BANDwidth:ACHannel command. Steep-edged channel filters are available
		for fast ACLR measurements. \n
			:param bandwidth: Range: 100 Hz to 1000 MHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'SENSe:POWer:ACHannel:BWIDth:UACHannel {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:BWIDth:UACHannel \n
		Snippet: value: float = driver.sense.power.achannel.bandwidth.uaChannel.get() \n
		This command defines the channel bandwidth of the upper adjacent channel in asymmetrical configurations. The adjacent
		channel is the first pair of channels next to the transmission channels. To configure the bandwidth for the lower
		adjacent channel, use the [SENSe:]POWer:ACHannel:BANDwidth:ACHannel command. Steep-edged channel filters are available
		for fast ACLR measurements. \n
			:return: bandwidth: Range: 100 Hz to 1000 MHz, Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:BWIDth:UACHannel?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:SWEep:TIME:AUTO \n
		Snippet: driver.applications.k18AmplifierEt.sense.sweep.time.auto.set(state = False) \n
		This command turns automatic selection of an appropriate capture time on and off. When you turn on this feature, the
		application calculates an appropriate capture time based on the reference signal and adjusts the other acquisition
		settings accordingly. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:SWEep:TIME:AUTO {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:SWEep:TIME:AUTO \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.sense.sweep.time.auto.get() \n
		This command turns automatic selection of an appropriate capture time on and off. When you turn on this feature, the
		application calculates an appropriate capture time based on the reference signal and adjusts the other acquisition
		settings accordingly. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'SENSe:SWEep:TIME:AUTO?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	@property
	def ledState(self):
		"""ledState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ledState'):
			from .LedState import LedStateCls
			self._ledState = LedStateCls(self._core, self._cmd_group)
		return self._ledState

	def set(self, level: float) -> None:
		"""SCPI: CONFigure:GENerator:POWer:LEVel:OFFSet \n
		Snippet: driver.applications.k18AmplifierEt.configure.generator.power.level.offset.set(level = 1.0) \n
		This command defines a mathematical level offset for the signal generator (for example to take external attenuation into
		account) . Make sure to synchronize with *OPC? or *WAI to make sure that the command was successfully applied on the
		generator before sending the next command. \n
			:param level: numeric value Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'CONFigure:GENerator:POWer:LEVel:OFFSet {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:GENerator:POWer:LEVel:OFFSet \n
		Snippet: value: float = driver.applications.k18AmplifierEt.configure.generator.power.level.offset.get() \n
		This command defines a mathematical level offset for the signal generator (for example to take external attenuation into
		account) . Make sure to synchronize with *OPC? or *WAI to make sure that the command was successfully applied on the
		generator before sending the next command. \n
			:return: level: numeric value Unit: dBm"""
		response = self._core.io.query_str(f'CONFigure:GENerator:POWer:LEVel:OFFSet?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'OffsetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OffsetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AcquireCls:
	"""Acquire commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("acquire", core, parent)

	def set(self, meas_type: enums.CorrectionMeasType) -> None:
		"""SCPI: [SENSe]:CORRection:COLLect[:ACQuire] \n
		Snippet: driver.sense.correction.collect.acquire.set(meas_type = enums.CorrectionMeasType.OPEN) \n
		This command initiates a reference measurement (calibration) . The reference measurement is the basis for the measurement
		normalization. The result depends on whether a reflection measurement or transmission measurement is performed (see
		[SENSe:]CORRection:METHod) . To obtain a correct reference measurement, a complete sweep with synchronization to the end
		of the sweep must have been carried out. This is only possible in the single sweep mode. This command is only available
		if External Generator Control (R&S FSW-B10) is installed and active. \n
			:param meas_type: THRough | OPEN THRough 'TRANsmission' mode: calibration with direct connection between generator and device input 'REFLection' mode: calibration with short circuit at the input OPEN only allowed in 'REFLection' mode: calibration with open input
		"""
		param = Conversions.enum_scalar_to_str(meas_type, enums.CorrectionMeasType)
		self._core.io.write(f'SENSe:CORRection:COLLect:ACQuire {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 10 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	@property
	def bandwidth(self):
		"""bandwidth commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def iqWindow(self):
		"""iqWindow commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iqWindow'):
			from .IqWindow import IqWindowCls
			self._iqWindow = IqWindowCls(self._core, self._cmd_group)
		return self._iqWindow

	@property
	def sweep(self):
		"""sweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def range(self):
		"""range commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_range'):
			from .Range import RangeCls
			self._range = RangeCls(self._core, self._cmd_group)
		return self._range

	def clone(self) -> 'ListPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ListPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AlpModeCls:
	"""AlpMode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("alpMode", core, parent)

	def set(self, mode: enums.AcpLimitEvalMode) -> None:
		"""SCPI: [SENSe]:NR5G:ACPower:ALPMode \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.acPower.alpMode.set(mode = enums.AcpLimitEvalMode.ABSolute) \n
		This command selects the limit evaluation mode for ACLR measurements in combined measurement mode. \n
			:param mode: ABSolute Checks against the absolute limits. RELative Checks against the relative limits. OR Checks against both absolute and relative limits according to 3GPP.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AcpLimitEvalMode)
		self._core.io.write(f'SENSe:NR5G:ACPower:ALPMode {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AcpLimitEvalMode:
		"""SCPI: [SENSe]:NR5G:ACPower:ALPMode \n
		Snippet: value: enums.AcpLimitEvalMode = driver.applications.k14Xnr5G.sense.nr5G.acPower.alpMode.get() \n
		This command selects the limit evaluation mode for ACLR measurements in combined measurement mode. \n
			:return: mode: ABSolute Checks against the absolute limits. RELative Checks against the relative limits. OR Checks against both absolute and relative limits according to 3GPP."""
		response = self._core.io.query_str(f'SENSe:NR5G:ACPower:ALPMode?')
		return Conversions.str_to_scalar_enum(response, enums.AcpLimitEvalMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EhtPpduCls:
	"""EhtPpdu commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ehtPpdu", core, parent)

	def set(self, ru_config_ppdu: enums.RuConfigPpdu) -> None:
		"""SCPI: CONFigure:WLAN:RUConfig:EHTPpdu \n
		Snippet: driver.applications.k91Wlan.configure.wlan.ruConfig.ehtPpdu.set(ru_config_ppdu = enums.RuConfigPpdu.ESU) \n
		Defines the format of the EHT PPDU. This format determines which other PPDU settings are available. \n
			:param ru_config_ppdu: MU High-efficiency multi-user PPDU for downlink to multiple users at the same time
		"""
		param = Conversions.enum_scalar_to_str(ru_config_ppdu, enums.RuConfigPpdu)
		self._core.io.write(f'CONFigure:WLAN:RUConfig:EHTPpdu {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.RuConfigPpdu:
		"""SCPI: CONFigure:WLAN:RUConfig:EHTPpdu \n
		Snippet: value: enums.RuConfigPpdu = driver.applications.k91Wlan.configure.wlan.ruConfig.ehtPpdu.get() \n
		Defines the format of the EHT PPDU. This format determines which other PPDU settings are available. \n
			:return: ru_config_ppdu: MU High-efficiency multi-user PPDU for downlink to multiple users at the same time"""
		response = self._core.io.query_str(f'CONFigure:WLAN:RUConfig:EHTPpdu?')
		return Conversions.str_to_scalar_enum(response, enums.RuConfigPpdu)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SinfoCls:
	"""Sinfo commands group definition. 5 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sinfo", core, parent)

	@property
	def cfactor(self):
		"""cfactor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cfactor'):
			from .Cfactor import CfactorCls
			self._cfactor = CfactorCls(self._core, self._cmd_group)
		return self._cfactor

	@property
	def fpath(self):
		"""fpath commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fpath'):
			from .Fpath import FpathCls
			self._fpath = FpathCls(self._core, self._cmd_group)
		return self._fpath

	@property
	def obw(self):
		"""obw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_obw'):
			from .Obw import ObwCls
			self._obw = ObwCls(self._core, self._cmd_group)
		return self._obw

	@property
	def slength(self):
		"""slength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_slength'):
			from .Slength import SlengthCls
			self._slength = SlengthCls(self._core, self._cmd_group)
		return self._slength

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	def clone(self) -> 'SinfoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SinfoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EventsCls:
	"""Events commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("events", core, parent)

	def set(self, events: float) -> None:
		"""SCPI: [SENSe]:SWEep:SCAPture:EVENts \n
		Snippet: driver.applications.k14Xnr5G.sense.sweep.scapture.events.set(events = 1.0) \n
		This command defines the number of segments to capture.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select external of IF power trigger source (TRIGger[:SEQuence]:SOURce<ant>) .
			- Turn on segmented capture ([SENSe:]SWEep:SCAPture:STATe) . \n
			:param events: No help available
		"""
		param = Conversions.decimal_value_to_str(events)
		self._core.io.write(f'SENSe:SWEep:SCAPture:EVENts {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:SCAPture:EVENts \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.sweep.scapture.events.get() \n
		This command defines the number of segments to capture.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select external of IF power trigger source (TRIGger[:SEQuence]:SOURce<ant>) .
			- Turn on segmented capture ([SENSe:]SWEep:SCAPture:STATe) . \n
			:return: events: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:SCAPture:EVENts?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SequenceCls:
	"""Sequence commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sequence", core, parent)

	def set(self, source: enums.SourceSequence) -> None:
		"""SCPI: TRIGger:TSHelper:SEQuence \n
		Snippet: driver.applications.k14Xnr5G.trigger.tsHelper.sequence.set(source = enums.SourceSequence.CLOop) \n
		This command select the type of measurement sequence for combined measurement. \n
			:param source: The selected sequence has an impact on the trigger settings. If you select a certain sequence and change, for example, the trigger source or trigger input / output configuration, the sequence type automatically returns to manual. CLOop Closed-loop sequence. MANual Custom trigger configuration. OLOop Open-loop sequence. PERiodic Periodic sequence.
		"""
		param = Conversions.enum_scalar_to_str(source, enums.SourceSequence)
		self._core.io.write(f'TRIGger:TSHelper:SEQuence {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SourceSequence:
		"""SCPI: TRIGger:TSHelper:SEQuence \n
		Snippet: value: enums.SourceSequence = driver.applications.k14Xnr5G.trigger.tsHelper.sequence.get() \n
		This command select the type of measurement sequence for combined measurement. \n
			:return: source: The selected sequence has an impact on the trigger settings. If you select a certain sequence and change, for example, the trigger source or trigger input / output configuration, the sequence type automatically returns to manual. CLOop Closed-loop sequence. MANual Custom trigger configuration. OLOop Open-loop sequence. PERiodic Periodic sequence."""
		response = self._core.io.query_str(f'TRIGger:TSHelper:SEQuence?')
		return Conversions.str_to_scalar_enum(response, enums.SourceSequence)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CfactorCls:
	"""Cfactor commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cfactor", core, parent)

	def get(self) -> float:
		"""SCPI: CONFigure:REFSignal:SINFo:CFACtor \n
		Snippet: value: float = driver.applications.k18AmplifierEt.configure.refSignal.sinfo.cfactor.get() \n
		Returns the crest factor of the reference signal. \n
			:return: crest_factor: numeric value"""
		response = self._core.io.query_str(f'CONFigure:REFSignal:SINFo:CFACtor?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TABLe:FREQuency:ALL[:STATe] \n
		Snippet: driver.applications.k6Pulse.calculate.table.frequency.all.state.set(state = False, window = repcap.Window.Default) \n
		If enabled, all frequency parameters are included in the result tables. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TABLe:FREQuency:ALL:STATe {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DetectorCls:
	"""Detector commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("detector", core, parent)

	def set(self, detector: enums.DetectorA, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:FMEasurement:DETector \n
		Snippet: driver.calculate.deltaMarker.function.fmeasurement.detector.set(detector = enums.DetectorA.ACSine, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command selects the detector for a specific marker during the final measurement. If the marker is not yet active,
		the command also turns the marker on. \n
			:param detector: OFF no final measurement is performed AVER average detector CAV CISPR Average detector CRMS RMS Average detector POS maximum peak detector QPE quasipeak detector
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
		"""
		param = Conversions.enum_scalar_to_str(detector, enums.DetectorA)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:FMEasurement:DETector {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> enums.DetectorA:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:FMEasurement:DETector \n
		Snippet: value: enums.DetectorA = driver.calculate.deltaMarker.function.fmeasurement.detector.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command selects the detector for a specific marker during the final measurement. If the marker is not yet active,
		the command also turns the marker on. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: detector: OFF no final measurement is performed AVER average detector CAV CISPR Average detector CRMS RMS Average detector POS maximum peak detector QPE quasipeak detector"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:FMEasurement:DETector?')
		return Conversions.str_to_scalar_enum(response, enums.DetectorA)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VtoleranceCls:
	"""Vtolerance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("vtolerance", core, parent)

	def set(self, tolerance: float) -> None:
		"""SCPI: [SENSe]:CESTimation:VTOLerance \n
		Snippet: driver.applications.k17Mcgd.sense.cestimation.vtolerance.set(tolerance = 1.0) \n
		Defines an additional tolerance to the Max relative Satellite Velocity in %. This information is used to calculate the
		Max Clock Offset. \n
			:param tolerance: numeric value Unit: %
		"""
		param = Conversions.decimal_value_to_str(tolerance)
		self._core.io.write(f'SENSe:CESTimation:VTOLerance {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CESTimation:VTOLerance \n
		Snippet: value: float = driver.applications.k17Mcgd.sense.cestimation.vtolerance.get() \n
		Defines an additional tolerance to the Max relative Satellite Velocity in %. This information is used to calculate the
		Max Clock Offset. \n
			:return: tolerance: numeric value Unit: %"""
		response = self._core.io.query_str(f'SENSe:CESTimation:VTOLerance?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AttRatioCls:
	"""AttRatio commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("attRatio", core, parent)

	def set(self, attenuation_ratio: float, probe=repcap.Probe.Default) -> None:
		"""SCPI: [SENSe]:PROBe<pb>:SETup:ATTRatio \n
		Snippet: driver.applications.k40PhaseNoise.sense.probe.setup.attRatio.set(attenuation_ratio = 1.0, probe = repcap.Probe.Default) \n
		No command help available \n
			:param attenuation_ratio: No help available
			:param probe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Probe')
		"""
		param = Conversions.decimal_value_to_str(attenuation_ratio)
		probe_cmd_val = self._cmd_group.get_repcap_cmd_value(probe, repcap.Probe)
		self._core.io.write(f'SENSe:PROBe{probe_cmd_val}:SETup:ATTRatio {param}')

	def get(self, probe=repcap.Probe.Default) -> float:
		"""SCPI: [SENSe]:PROBe<pb>:SETup:ATTRatio \n
		Snippet: value: float = driver.applications.k40PhaseNoise.sense.probe.setup.attRatio.get(probe = repcap.Probe.Default) \n
		No command help available \n
			:param probe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Probe')
			:return: attenuation_ratio: No help available"""
		probe_cmd_val = self._cmd_group.get_repcap_cmd_value(probe, repcap.Probe)
		response = self._core.io.query_str(f'SENSe:PROBe{probe_cmd_val}:SETup:ATTRatio?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.MarkerMode, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:BPOWer:MODE \n
		Snippet: driver.calculate.deltaMarker.function.bpower.mode.set(mode = enums.MarkerMode.DENSity, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command selects the way the results for a band power delta marker are displayed. \n
			:param mode: POWer Result is displayed as an absolute power. The power unit depends on the method RsFsw.Applications.K91_Wlan.Calculate.Unit.Power.set setting. DENSity Result is displayed as a density in dBm/Hz. RPOWer This setting is only available for a delta band power marker. The result is the difference between the absolute power in the band around the delta marker and the absolute power for the reference marker. The powers are subtracted logarithmically, so the result is a dB value. [Relative band power (Delta2) in dB] = [absolute band power (Delta2) in dBm] - [absolute (band) power of reference marker in dBm] For details see 'Relative band power markers'.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.MarkerMode)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:BPOWer:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> enums.MarkerMode:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:BPOWer:MODE \n
		Snippet: value: enums.MarkerMode = driver.calculate.deltaMarker.function.bpower.mode.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command selects the way the results for a band power delta marker are displayed. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: mode: POWer Result is displayed as an absolute power. The power unit depends on the method RsFsw.Applications.K91_Wlan.Calculate.Unit.Power.set setting. DENSity Result is displayed as a density in dBm/Hz. RPOWer This setting is only available for a delta band power marker. The result is the difference between the absolute power in the band around the delta marker and the absolute power for the reference marker. The powers are subtracted logarithmically, so the result is a dB value. [Relative band power (Delta2) in dB] = [absolute band power (Delta2) in dBm] - [absolute (band) power of reference marker in dBm] For details see 'Relative band power markers'."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:BPOWer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.MarkerMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, offset: float, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: [SENSe]:FREQuency:CENTer[:CC<cc>]:OFFSet \n
		Snippet: driver.applications.k14Xnr5G.sense.frequency.center.cc.offset.set(offset = 1.0, carrierComponent = repcap.CarrierComponent.Default) \n
		This command defines the general frequency offset.
			INTRO_CMD_HELP: For measurements on multiple component carriers, the command defines the frequency offset for a component carrier. The effect of the command depends on the syntax: \n
			- When you omit the [CC<cc>] syntax element, the command defines the overall frequency offset. In that case, the value is added to the measurement frequency and, in case of measurements with component carriers, the center frequency of the component carriers.
			- When you include the [CC<cc>] syntax element, the command defines the offset of the component carrier relative the first component carrier. In that case, the command is not available for the first component carrier - thus, ...:CC1:... is not possible.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select the first component carrier (CC1) as the reference point for the frequency offset (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Orel.set) . \n
			:param offset: numeric value • General frequency offset: frequency offset in Hz. • Component carrier offset: frequency offset relative to the first component carrier in Hz. Unit: Hz
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.decimal_value_to_str(offset)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'SENSe:FREQuency:CENTer:CC{carrierComponent_cmd_val}:OFFSet {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
		"""SCPI: [SENSe]:FREQuency:CENTer[:CC<cc>]:OFFSet \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.frequency.center.cc.offset.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command defines the general frequency offset.
			INTRO_CMD_HELP: For measurements on multiple component carriers, the command defines the frequency offset for a component carrier. The effect of the command depends on the syntax: \n
			- When you omit the [CC<cc>] syntax element, the command defines the overall frequency offset. In that case, the value is added to the measurement frequency and, in case of measurements with component carriers, the center frequency of the component carriers.
			- When you include the [CC<cc>] syntax element, the command defines the offset of the component carrier relative the first component carrier. In that case, the command is not available for the first component carrier - thus, ...:CC1:... is not possible.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select the first component carrier (CC1) as the reference point for the frequency offset (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Orel.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: offset: numeric value • General frequency offset: frequency offset in Hz. • Component carrier offset: frequency offset relative to the first component carrier in Hz. Unit: Hz"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'SENSe:FREQuency:CENTer:CC{carrierComponent_cmd_val}:OFFSet?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResolutionCls:
	"""Resolution commands group definition. 5 total commands, 4 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("resolution", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def filterPy(self):
		"""filterPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def ratio(self):
		"""ratio commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ratio'):
			from .Ratio import RatioCls
			self._ratio = RatioCls(self._core, self._cmd_group)
		return self._ratio

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def set(self, bandwidth: float) -> None:
		"""SCPI: [SENSe]:BWIDth[:RESolution] \n
		Snippet: driver.applications.k10Xlte.sense.bandwidth.resolution.set(bandwidth = 1.0) \n
		No command help available \n
			:param bandwidth: No help available
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'SENSe:BWIDth:RESolution {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:BWIDth[:RESolution] \n
		Snippet: value: float = driver.applications.k10Xlte.sense.bandwidth.resolution.get() \n
		No command help available \n
			:return: bandwidth: No help available"""
		response = self._core.io.query_str(f'SENSe:BWIDth:RESolution?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'ResolutionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResolutionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CycPrefixCls:
	"""CycPrefix commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cycPrefix", core, parent)

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.CycPrefixType:
		"""SCPI: FETCh[:CC<cc>]:CYCPrefix \n
		Snippet: value: enums.CycPrefixType = driver.applications.k10Xlte.fetch.cc.cycPrefix.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command queries the cyclic prefix type that has been detected. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: prefix_type: The command returns -1 if no valid result has been detected yet. NORM Normal cyclic prefix length detected EXT Extended cyclic prefix length detected"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'FETCh:CC{carrierComponent_cmd_val}:CYCPrefix?')
		return Conversions.str_to_scalar_enum(response, enums.CycPrefixType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CategoryCls:
	"""Category commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("category", core, parent)

	@property
	def b(self):
		"""b commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_b'):
			from .B import BCls
			self._b = BCls(self._core, self._cmd_group)
		return self._b

	def set(self, category: enums.PowerCategory) -> None:
		"""SCPI: [SENSe]:POWer:CATegory \n
		Snippet: driver.applications.k14Xnr5G.sense.power.category.set(category = enums.PowerCategory.A) \n
		This command selects the base station category- \n
			:param category: A Category A base station. B Category B base station. LARE Large area base station. MED Medium area base station.
		"""
		param = Conversions.enum_scalar_to_str(category, enums.PowerCategory)
		self._core.io.write(f'SENSe:POWer:CATegory {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PowerCategory:
		"""SCPI: [SENSe]:POWer:CATegory \n
		Snippet: value: enums.PowerCategory = driver.applications.k14Xnr5G.sense.power.category.get() \n
		This command selects the base station category- \n
			:return: category: A Category A base station. B Category B base station. LARE Large area base station. MED Medium area base station."""
		response = self._core.io.query_str(f'SENSe:POWer:CATegory?')
		return Conversions.str_to_scalar_enum(response, enums.PowerCategory)

	def clone(self) -> 'CategoryCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CategoryCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def set(self, start_frequency: float, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe]:STARt \n
		Snippet: driver.applications.k40PhaseNoise.display.window.trace.x.scale.start.set(start_frequency = 1.0, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command selects the start frequency of the display range. Before you can use the command you have to select a manual
		display range for the x-axis with method RsFsw.Applications.K40_PhaseNoise.Display.Window.Trace.X.Scale.Scope.set. \n
			:param start_frequency: Start offset frequency of a half decade. Note that the start offset you want to display has to be part of the current measurement range. Range: 100 mHz to 3 GHz, Unit: HZ
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.decimal_value_to_str(start_frequency)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe:STARt {param}')

	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe]:STARt \n
		Snippet: value: float = driver.applications.k40PhaseNoise.display.window.trace.x.scale.start.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command selects the start frequency of the display range. Before you can use the command you have to select a manual
		display range for the x-axis with method RsFsw.Applications.K40_PhaseNoise.Display.Window.Trace.X.Scale.Scope.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: start_frequency: Start offset frequency of a half decade. Note that the start offset you want to display has to be part of the current measurement range. Range: 100 mHz to 3 GHz, Unit: HZ"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe:STARt?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PtypeCls:
	"""Ptype commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ptype", core, parent)

	def set(self, pad_type: enums.PadType, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:IQ:IMPedance:PTYPe \n
		Snippet: driver.applications.k70Vsa.inputPy.iq.impedance.ptype.set(pad_type = enums.PadType.MLPad, inputIx = repcap.InputIx.Default) \n
		Defines the type of matching pad used for impedance conversion for analog baseband input. For RF input, use the method
		RsFsw.InputPy.Impedance.Ptype.set command. \n
			:param pad_type: SRESistor | MLPad SRESistor Series-R MLPad Minimum Loss Pad
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(pad_type, enums.PadType)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:IQ:IMPedance:PTYPe {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.PadType:
		"""SCPI: INPut<ip>:IQ:IMPedance:PTYPe \n
		Snippet: value: enums.PadType = driver.applications.k70Vsa.inputPy.iq.impedance.ptype.get(inputIx = repcap.InputIx.Default) \n
		Defines the type of matching pad used for impedance conversion for analog baseband input. For RF input, use the method
		RsFsw.InputPy.Impedance.Ptype.set command. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: pad_type: SRESistor | MLPad SRESistor Series-R MLPad Minimum Loss Pad"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IQ:IMPedance:PTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.PadType)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, meas_type: enums.MeasurementTypeK91) -> None:
		"""SCPI: CONFigure:BURSt:SPECtrum:FLATness:SELect \n
		Snippet: driver.applications.k91Wlan.configure.burst.spectrum.flatness.select.set(meas_type = enums.MeasurementTypeK91.FLATness) \n
		This remote control command configures result display type of window 2 to be either 'Spectrum Flatness' or 'Group Delay'.
		Results are only displayed after a measurement is executed, e.g. using the method RsFsw.Applications.K10x_Lte.Initiate.
		Immediate.set command. Note that the CONF:BURS:<ResultType>:IMM commands change the screen layout to display the
		'Magnitude Capture' buffer in window 1 at the top of the screen and the selected result type in window 2 below that. Any
		other active windows are closed. Use the LAYout commands to change the display (see 'Working with windows in the
		display') . \n
			:param meas_type: FLATness | GRDelay
		"""
		param = Conversions.enum_scalar_to_str(meas_type, enums.MeasurementTypeK91)
		self._core.io.write(f'CONFigure:BURSt:SPECtrum:FLATness:SELect {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.MeasurementTypeK91:
		"""SCPI: CONFigure:BURSt:SPECtrum:FLATness:SELect \n
		Snippet: value: enums.MeasurementTypeK91 = driver.applications.k91Wlan.configure.burst.spectrum.flatness.select.get() \n
		This remote control command configures result display type of window 2 to be either 'Spectrum Flatness' or 'Group Delay'.
		Results are only displayed after a measurement is executed, e.g. using the method RsFsw.Applications.K10x_Lte.Initiate.
		Immediate.set command. Note that the CONF:BURS:<ResultType>:IMM commands change the screen layout to display the
		'Magnitude Capture' buffer in window 1 at the top of the screen and the selected result type in window 2 below that. Any
		other active windows are closed. Use the LAYout commands to change the display (see 'Working with windows in the
		display') . \n
			:return: meas_type: FLATness | GRDelay"""
		response = self._core.io.query_str(f'CONFigure:BURSt:SPECtrum:FLATness:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.MeasurementTypeK91)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from ..........Internal.Types import DataType
from ..........Internal.ArgSingleList import ArgSingleList
from ..........Internal.ArgSingle import ArgSingle
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RelativeCls:
	"""Relative commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("relative", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, sb_gaps: enums.SubBlockGaps, limit: float, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>:MANual:UPPer[:CACLr][:RELative] \n
		Snippet: driver.calculate.limit.acPower.gap.manual.upper.caclr.relative.set(sb_gaps = enums.SubBlockGaps.AB, limit = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		This command defines the relative limit of the specified upper gap (CACLR) channel. The reference value for the relative
		limit is the measured channel power. If you define both an absolute limit and a relative limit, the R&S FSW uses the
		lower value for the limit check. This command is only available for for asymmetrical (manual) configuration of gap
		channels (see [SENSe:]POWer:ACHannel:GAP<gap>:MODE) . \n
			:param sb_gaps: AB | BC | CD | DE | EF | FG | GH Name of the gap, defined by the letters of the surrounding sub blocks (e.g. 'AB' for the gap between sub blocks A and B) .
			:param limit: Defines the relative limit of the specified gap channel in dB. Unit: DB
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('sb_gaps', sb_gaps, DataType.Enum, enums.SubBlockGaps), ArgSingle('limit', limit, DataType.Float))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:MANual:UPPer:CACLr:RELative {param}'.rstrip())

	def get(self, sb_gaps: enums.SubBlockGaps, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>:MANual:UPPer[:CACLr][:RELative] \n
		Snippet: value: float = driver.calculate.limit.acPower.gap.manual.upper.caclr.relative.get(sb_gaps = enums.SubBlockGaps.AB, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		This command defines the relative limit of the specified upper gap (CACLR) channel. The reference value for the relative
		limit is the measured channel power. If you define both an absolute limit and a relative limit, the R&S FSW uses the
		lower value for the limit check. This command is only available for for asymmetrical (manual) configuration of gap
		channels (see [SENSe:]POWer:ACHannel:GAP<gap>:MODE) . \n
			:param sb_gaps: AB | BC | CD | DE | EF | FG | GH Name of the gap, defined by the letters of the surrounding sub blocks (e.g. 'AB' for the gap between sub blocks A and B) .
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: limit: Defines the relative limit of the specified gap channel in dB. Unit: DB"""
		param = Conversions.enum_scalar_to_str(sb_gaps, enums.SubBlockGaps)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:MANual:UPPer:CACLr:RELative? {param}')
		return Conversions.str_to_float(response)

	def clone(self) -> 'RelativeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RelativeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:POWer:SEM:AMPower:AUTO \n
		Snippet: driver.applications.k14Xnr5G.sense.power.sem.amPower.auto.set(state = False) \n
		This command selects how the R&S FSW determines the power of a medium range base station.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a medium range base station ([SENSe:]POWer:CATegory) . \n
			:param state: ON | 1 Automatically determines the Tx power. OFF | 0 Define a Tx power manually with [SENSe:]POWer:SEM:AMPower.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:POWer:SEM:AMPower:AUTO {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:POWer:SEM:AMPower:AUTO \n
		Snippet: value: bool = driver.applications.k14Xnr5G.sense.power.sem.amPower.auto.get() \n
		This command selects how the R&S FSW determines the power of a medium range base station.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a medium range base station ([SENSe:]POWer:CATegory) . \n
			:return: state: ON | 1 Automatically determines the Tx power. OFF | 0 Define a Tx power manually with [SENSe:]POWer:SEM:AMPower."""
		response = self._core.io.query_str(f'SENSe:POWer:SEM:AMPower:AUTO?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AverageCls:
	"""Average commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("average", core, parent)

	def set(self, value: float) -> None:
		"""SCPI: CONFigure:BURSt:PVT:AVERage \n
		Snippet: driver.applications.k91Wlan.configure.burst.pvt.average.set(value = 1.0) \n
		Defines the number of samples used to adjust the length of the smoothing filter for PVT measurement. This command is only
		available for IEEE 802.11b, g (DSSS) standards. \n
			:param value: No help available
		"""
		param = Conversions.decimal_value_to_str(value)
		self._core.io.write(f'CONFigure:BURSt:PVT:AVERage {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:BURSt:PVT:AVERage \n
		Snippet: value: float = driver.applications.k91Wlan.configure.burst.pvt.average.get() \n
		Defines the number of samples used to adjust the length of the smoothing filter for PVT measurement. This command is only
		available for IEEE 802.11b, g (DSSS) standards. \n
			:return: value: No help available"""
		response = self._core.io.query_str(f'CONFigure:BURSt:PVT:AVERage?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: CONFigure:REFSignal:CWF:ETGenerator[:STATe] \n
		Snippet: driver.applications.k18AmplifierEt.configure.refSignal.cwf.etGenerator.state.set(state = False) \n
		This command turns the transfer of the reference signal data to a generator on and off.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Generate reference signal with a waveform file \n
			:param state: ON | 1 Reference signal data is transferred to the generator and generated with the generator. OFF | 0 Reference signal data is loaded into the application without transferring the waveform to the generator. When you turn it off, you have to define the peak input power of the DUT with method RsFsw.Applications.K18_AmplifierEt.Configure.RefSignal.Cwf.DpiPower.set. Otherwise, measurement result may be invalid.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:REFSignal:CWF:ETGenerator:STATe {param}')

	def get(self) -> bool:
		"""SCPI: CONFigure:REFSignal:CWF:ETGenerator[:STATe] \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.configure.refSignal.cwf.etGenerator.state.get() \n
		This command turns the transfer of the reference signal data to a generator on and off.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Generate reference signal with a waveform file \n
			:return: state: ON | 1 Reference signal data is transferred to the generator and generated with the generator. OFF | 0 Reference signal data is loaded into the application without transferring the waveform to the generator. When you turn it off, you have to define the peak input power of the DUT with method RsFsw.Applications.K18_AmplifierEt.Configure.RefSignal.Cwf.DpiPower.set. Otherwise, measurement result may be invalid."""
		response = self._core.io.query_str(f'CONFigure:REFSignal:CWF:ETGenerator:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: INPut:DIQ:RANGe[:UPPer]:AUTO \n
		Snippet: driver.inputPy.diq.range.upper.auto.set(state = False) \n
		If enabled, the digital input full scale level is automatically set to the value provided by the connected device (if
		available) . This command is only available if the optional 'Digital Baseband' interface is installed. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'INPut:DIQ:RANGe:UPPer:AUTO {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HspeedCls:
	"""Hspeed commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hspeed", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:POWer:HSPeed \n
		Snippet: driver.sense.power.hspeed.set(state = False) \n
		This command turns high speed ACLR and channel power measurements on and off. If on, the R&S FSW performs a measurement
		on each channel in the time domain. It returns to the frequency domain when the measurement is done.
		In some telecommunications standards, high speed measurements use weighting filters with characteristic or steep-edged
		channel filters for band limitation. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:POWer:HSPeed {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:POWer:HSPeed \n
		Snippet: value: bool = driver.sense.power.hspeed.get() \n
		This command turns high speed ACLR and channel power measurements on and off. If on, the R&S FSW performs a measurement
		on each channel in the time domain. It returns to the frequency domain when the measurement is done.
		In some telecommunications standards, high speed measurements use weighting filters with characteristic or steep-edged
		channel filters for band limitation. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'SENSe:POWer:HSPeed?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TsidelobeCls:
	"""Tsidelobe commands group definition. 32 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tsidelobe", core, parent)

	@property
	def all(self):
		"""all commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def psLevel(self):
		"""psLevel commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_psLevel'):
			from .PsLevel import PsLevelCls
			self._psLevel = PsLevelCls(self._core, self._cmd_group)
		return self._psLevel

	@property
	def isLevel(self):
		"""isLevel commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_isLevel'):
			from .IsLevel import IsLevelCls
			self._isLevel = IsLevelCls(self._core, self._cmd_group)
		return self._isLevel

	@property
	def mwidth(self):
		"""mwidth commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_mwidth'):
			from .Mwidth import MwidthCls
			self._mwidth = MwidthCls(self._core, self._cmd_group)
		return self._mwidth

	@property
	def sdelay(self):
		"""sdelay commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_sdelay'):
			from .Sdelay import SdelayCls
			self._sdelay = SdelayCls(self._core, self._cmd_group)
		return self._sdelay

	@property
	def cratio(self):
		"""cratio commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_cratio'):
			from .Cratio import CratioCls
			self._cratio = CratioCls(self._core, self._cmd_group)
		return self._cratio

	@property
	def imPower(self):
		"""imPower commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_imPower'):
			from .ImPower import ImPowerCls
			self._imPower = ImPowerCls(self._core, self._cmd_group)
		return self._imPower

	@property
	def amPower(self):
		"""amPower commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_amPower'):
			from .AmPower import AmPowerCls
			self._amPower = AmPowerCls(self._core, self._cmd_group)
		return self._amPower

	@property
	def pcorrelation(self):
		"""pcorrelation commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_pcorrelation'):
			from .Pcorrelation import PcorrelationCls
			self._pcorrelation = PcorrelationCls(self._core, self._cmd_group)
		return self._pcorrelation

	@property
	def mphase(self):
		"""mphase commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_mphase'):
			from .Mphase import MphaseCls
			self._mphase = MphaseCls(self._core, self._cmd_group)
		return self._mphase

	@property
	def mfrequency(self):
		"""mfrequency commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_mfrequency'):
			from .Mfrequency import MfrequencyCls
			self._mfrequency = MfrequencyCls(self._core, self._cmd_group)
		return self._mfrequency

	def clone(self) -> 'TsidelobeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TsidelobeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OrelCls:
	"""Orel commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("orel", core, parent)

	def set(self, mode: enums.RefPointMode) -> None:
		"""SCPI: CONFigure[:NR5G]:OREL \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.orel.set(mode = enums.RefPointMode.CC1) \n
		This command selects the reference point for frequency offsets of component carriers in a multicarrier setup. \n
			:param mode: CC1 Reference point is the center frequency of first component carrier. GMCFreq Reference point the global multicarrier frequency.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.RefPointMode)
		self._core.io.write(f'CONFigure:NR5G:OREL {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.RefPointMode:
		"""SCPI: CONFigure[:NR5G]:OREL \n
		Snippet: value: enums.RefPointMode = driver.applications.k14Xnr5G.configure.nr5G.orel.get() \n
		This command selects the reference point for frequency offsets of component carriers in a multicarrier setup. \n
			:return: mode: No help available"""
		response = self._core.io.query_str(f'CONFigure:NR5G:OREL?')
		return Conversions.str_to_scalar_enum(response, enums.RefPointMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DemodSettingCls:
	"""DemodSetting commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("demodSetting", core, parent)

	def set(self, file: str, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: MMEMory:LOAD[:CC<cc>]:DEModsetting \n
		Snippet: driver.applications.k10Xlte.massMemory.load.cc.demodSetting.set(file = '1', carrierComponent = repcap.CarrierComponent.Default) \n
		This command restores previously saved demodulation settings. The file must be of type .allocation and depends on the
		link direction that was currently selected when the file was saved. You can load only files with correct link directions. \n
			:param file: String containing the path and name of the file.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.value_to_quoted_str(file)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'MMEMory:LOAD:CC{carrierComponent_cmd_val}:DEModsetting {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> str:
		"""SCPI: MMEMory:LOAD[:CC<cc>]:DEModsetting \n
		Snippet: value: str = driver.applications.k10Xlte.massMemory.load.cc.demodSetting.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command restores previously saved demodulation settings. The file must be of type .allocation and depends on the
		link direction that was currently selected when the file was saved. You can load only files with correct link directions. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: file: String containing the path and name of the file."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'MMEMory:LOAD:CC{carrierComponent_cmd_val}:DEModsetting?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfmCls:
	"""Rfm commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rfm", core, parent)

	def get(self, trace=repcap.Trace.Default, userRange=repcap.UserRange.Default) -> float:
		"""SCPI: FETCh:PNOise<t>:USER<range>:RFM \n
		Snippet: value: float = driver.applications.k40PhaseNoise.fetch.pnoise.user.rfm.get(trace = repcap.Trace.Default, userRange = repcap.UserRange.Default) \n
		This command queries the residual FM for a particular user range. The trace that is queried depends on method RsFsw.
		Applications.K40_PhaseNoise.Calculate.Evaluation.User.Trace.set. \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Pnoise')
			:param userRange: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: value: No help available"""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		userRange_cmd_val = self._cmd_group.get_repcap_cmd_value(userRange, repcap.UserRange)
		response = self._core.io.query_str(f'FETCh:PNOise{trace_cmd_val}:USER{userRange_cmd_val}:RFM?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VdeviceCls:
	"""Vdevice commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("vdevice", core, parent)

	def get(self, inputIx=repcap.InputIx.Default) -> float:
		"""SCPI: INPut<ip>:IQ:OSC:VDEVice \n
		Snippet: value: float = driver.inputPy.iq.osc.vdevice.get(inputIx = repcap.InputIx.Default) \n
		Queries whether the connected instrument is supported for Oscilloscope Baseband Input. For details see the data sheet. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: device: ON | OFF | 0 | 1 OFF | 0 Instrument is not supported. ON | 1 Instrument is supported"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IQ:OSC:VDEVice?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhrRateCls:
	"""PhrRate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phrRate", core, parent)

	def set(self, phr_rate: enums.PhrRate) -> None:
		"""SCPI: [SENSe]:DEMod:PHRRate \n
		Snippet: driver.applications.k149Uwb.sense.demod.phrRate.set(phr_rate = enums.PhrRate.BMHP) \n
		Selects PHY Mode/Rate modes. \n
			:param phr_rate: BMLP | BMHP | HMLR | HMHR
		"""
		param = Conversions.enum_scalar_to_str(phr_rate, enums.PhrRate)
		self._core.io.write(f'SENSe:DEMod:PHRRate {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PhrRate:
		"""SCPI: [SENSe]:DEMod:PHRRate \n
		Snippet: value: enums.PhrRate = driver.applications.k149Uwb.sense.demod.phrRate.get() \n
		Selects PHY Mode/Rate modes. \n
			:return: phr_rate: BMLP | BMHP | HMLR | HMHR"""
		response = self._core.io.query_str(f'SENSe:DEMod:PHRRate?')
		return Conversions.str_to_scalar_enum(response, enums.PhrRate)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BCls:
	"""B commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("b", core, parent)

	def set(self, value: float) -> None:
		"""SCPI: CONFigure:PAE:PCONsumption[:PARameter]:B \n
		Snippet: driver.applications.k18AmplifierEt.configure.pae.pconsumption.parameter.b.set(value = 1.0) \n
		No command help available \n
			:param value: No help available
		"""
		param = Conversions.decimal_value_to_str(value)
		self._core.io.write(f'CONFigure:PAE:PCONsumption:PARameter:B {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:PAE:PCONsumption[:PARameter]:B \n
		Snippet: value: float = driver.applications.k18AmplifierEt.configure.pae.pconsumption.parameter.b.get() \n
		No command help available \n
			:return: value: No help available"""
		response = self._core.io.query_str(f'CONFigure:PAE:PCONsumption:PARameter:B?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OstateCls:
	"""Ostate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ostate", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.ControlState:
		"""SCPI: CONFigure:GENerator:MCGD:OSTate \n
		Snippet: value: enums.ControlState = driver.applications.k17Mcgd.configure.generator.mcgd.ostate.get() \n
		Queries the overall status of the generator control settings. \n
			:return: state: OFF | SUCCessful | ERRor OFF Signal generator control off SUCCessful Connection established and all settings valid ERRor Control error, for example because a specified value cannot be applied on the signal generator"""
		response = self._core.io.query_str(f'CONFigure:GENerator:MCGD:OSTate?')
		return Conversions.str_to_scalar_enum(response, enums.ControlState)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DutGainCls:
	"""DutGain commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dutGain", core, parent)

	def set(self, level: float) -> None:
		"""SCPI: CONFigure:GENerator:LEVel:DUTGain \n
		Snippet: driver.applications.k14Xnr5G.configure.generator.level.dutGain.set(level = 1.0) \n
		This command defines DUT level gain for generator level control.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- IP connection to a signal generator.
			- Generator control state is on (method RsFsw.Applications.K18_AmplifierEt.Configure.Generator.Control.State.set) .
			- Level control is on (method RsFsw.Applications.K14x_Nr5G.Configure.Generator.Power.Level.State.set) . \n
			:param level: Unit: dB
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'CONFigure:GENerator:LEVel:DUTGain {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:GENerator:LEVel:DUTGain \n
		Snippet: value: float = driver.applications.k14Xnr5G.configure.generator.level.dutGain.get() \n
		This command defines DUT level gain for generator level control.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- IP connection to a signal generator.
			- Generator control state is on (method RsFsw.Applications.K18_AmplifierEt.Configure.Generator.Control.State.set) .
			- Level control is on (method RsFsw.Applications.K14x_Nr5G.Configure.Generator.Power.Level.State.set) . \n
			:return: level: Unit: dB"""
		response = self._core.io.query_str(f'CONFigure:GENerator:LEVel:DUTGain?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SaxesCls:
	"""Saxes commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("saxes", core, parent)

	def set(self, unit: enums.XaxisUnitScale) -> None:
		"""SCPI: UNIT:SAXes \n
		Snippet: driver.applications.k14Xnr5G.unit.saxes.set(unit = enums.XaxisUnitScale.SYMBol) \n
		This command selects the scale of the x-axis for result displays that show symbol results. \n
			:param unit: SYMBol Shows the number of the symbol on the x-axis. TIME Shows the time stamp of the symbols on the x-axis.
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.XaxisUnitScale)
		self._core.io.write(f'UNIT:SAXes {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.XaxisUnitScale:
		"""SCPI: UNIT:SAXes \n
		Snippet: value: enums.XaxisUnitScale = driver.applications.k14Xnr5G.unit.saxes.get() \n
		This command selects the scale of the x-axis for result displays that show symbol results. \n
			:return: unit: SYMBol Shows the number of the symbol on the x-axis. TIME Shows the time stamp of the symbols on the x-axis."""
		response = self._core.io.query_str(f'UNIT:SAXes?')
		return Conversions.str_to_scalar_enum(response, enums.XaxisUnitScale)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SwitchingCls:
	"""Switching commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("switching", core, parent)

	def set(self, state: bool, scaling: enums.TimeScaling = None, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:HOPDetection:TABLe:TIMing:SWITching \n
		Snippet: driver.applications.k60Transient.calculate.hopDetection.table.timing.switching.set(state = False, scaling = enums.TimeScaling.MS, window = repcap.Window.Default) \n
		If enabled, the specified time parameter is included in the result tables (see 'Timing parameters') . Note that only the
		enabled columns are returned for the method RsFsw.Applications.K60_Transient.Calculate.HopDetection.Table.Results.
		get_ query. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 The parameter is included. ON | 1 The parameter is not included
			:param scaling: S | MS | US | NS Defines the scaling for the timing parameters
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('state', state, DataType.Boolean), ArgSingle('scaling', scaling, DataType.Enum, enums.TimeScaling, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:HOPDetection:TABLe:TIMing:SWITching {param}'.rstrip())

	# noinspection PyTypeChecker
	class SwitchingStruct(StructBase):
		"""Response structure. Fields: \n
			- State: bool: ON | OFF | 0 | 1 OFF | 0 The parameter is included. ON | 1 The parameter is not included
			- Scaling: enums.TimeScaling: S | MS | US | NS Defines the scaling for the timing parameters"""
		__meta_args_list = [
			ArgStruct.scalar_bool('State'),
			ArgStruct.scalar_enum('Scaling', enums.TimeScaling)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.State: bool = None
			self.Scaling: enums.TimeScaling = None

	def get(self, window=repcap.Window.Default) -> SwitchingStruct:
		"""SCPI: CALCulate<n>:HOPDetection:TABLe:TIMing:SWITching \n
		Snippet: value: SwitchingStruct = driver.applications.k60Transient.calculate.hopDetection.table.timing.switching.get(window = repcap.Window.Default) \n
		If enabled, the specified time parameter is included in the result tables (see 'Timing parameters') . Note that only the
		enabled columns are returned for the method RsFsw.Applications.K60_Transient.Calculate.HopDetection.Table.Results.
		get_ query. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for SwitchingStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:HOPDetection:TABLe:TIMing:SWITching?', self.__class__.SwitchingStruct())



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CbIndexCls:
	"""CbIndex commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cbIndex", core, parent)

	def set(self, code_book_index: float, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default) -> None:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:SUBFrame<sf>:ALLoc:PRECoding:CBINdex \n
		Snippet: driver.applications.k10Xlte.configure.lte.uplink.cc.subframe.alloc.precoding.cbIndex.set(code_book_index = 1.0, carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default) \n
		This command selects the codebook index for a PUSCH allocation. \n
			:param code_book_index: Range: 0 to 5
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
		"""
		param = Conversions.decimal_value_to_str(code_book_index)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		self._core.io.write(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:SUBFrame{subframe_cmd_val}:ALLoc:PRECoding:CBINdex {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default) -> float:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:SUBFrame<sf>:ALLoc:PRECoding:CBINdex \n
		Snippet: value: float = driver.applications.k10Xlte.configure.lte.uplink.cc.subframe.alloc.precoding.cbIndex.get(carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default) \n
		This command selects the codebook index for a PUSCH allocation. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
			:return: code_book_index: Range: 0 to 5"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		response = self._core.io.query_str(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:SUBFrame{subframe_cmd_val}:ALLoc:PRECoding:CBINdex?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Trace, default value after init: Trace.Tr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_trace_get', 'repcap_trace_set', repcap.Trace.Tr1)

	def repcap_trace_set(self, trace: repcap.Trace) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Trace.Default
		Default value after init: Trace.Tr1"""
		self._cmd_group.set_repcap_enum_value(trace)

	def repcap_trace_get(self) -> repcap.Trace:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:ADEMod:FERRor[:RESult<t>] \n
		Snippet: value: float = driver.calculate.marker.function.ademod.freqError.result.get(window = repcap.Window.Default, marker = repcap.Marker.Default, trace = repcap.Trace.Default) \n
		This command queries the carrier offset (= frequency error) for FM and PM demodulation. The carrier offset is determined
		from the current measurement data (CLR/WRITE) . The modulation is removed using low pass filtering. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Result')
			:return: carr_offset: The deviation of the calculated carrier frequency to the ideal carrier frequency in Hz."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:ADEMod:FERRor:RESult{trace_cmd_val}?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'ResultCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResultCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:SELect \n
		Snippet: driver.display.window.subwindow.trace.select.set(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command selects the trace specified by the index <t> in the window specified by the index <n>. Only traces that are
		active in the specified result display can be selected. The selected trace is used to determine the 'Result Summary' for
		the corresponding result display. The query returns the number of the currently selected trace in the window specified by
		the index <n> (trace index is ignored) . Traces can only be queried for graphical result displays (not 'Result Summary',
		'Marker Table' or Peak Marker List) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:SELect')

	def set_with_opc(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:SELect \n
		Snippet: driver.display.window.subwindow.trace.select.set_with_opc(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command selects the trace specified by the index <t> in the window specified by the index <n>. Only traces that are
		active in the specified result display can be selected. The selected trace is used to determine the 'Result Summary' for
		the corresponding result display. The query returns the number of the currently selected trace in the window specified by
		the index <n> (trace index is ignored) . Traces can only be queried for graphical result displays (not 'Result Summary',
		'Marker Table' or Peak Marker List) . \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:SELect', opc_timeout_ms)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CidCls:
	"""Cid commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cid", core, parent)

	def set(self, cell_id: float, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:PLC:CID \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.plc.cid.set(cell_id = 1.0, carrierComponent = repcap.CarrierComponent.Default) \n
		This command defines the cell ID. \n
			:param cell_id: AUTO Automatically determines the cell ID. numeric value (integer only) Number of the cell ID. Range: 0 to 503
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.decimal_value_to_str(cell_id)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:PLC:CID {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:PLC:CID \n
		Snippet: value: float = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.plc.cid.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command defines the cell ID. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: cell_id: AUTO Automatically determines the cell ID. numeric value (integer only) Number of the cell ID. Range: 0 to 503"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:PLC:CID?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RelativeCls:
	"""Relative commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("relative", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, lower_limit: float, upper_limit: float = None, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:ACHannel[:RELative] \n
		Snippet: driver.calculate.limit.acPower.achannel.relative.set(lower_limit = 1.0, upper_limit = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command defines the relative limit of the adjacent channels. The reference value for the relative limit is the
		measured channel power. If you have defined an absolute limit as well as a relative limit, the R&S FSW uses the lower
		value for the limit check. \n
			:param lower_limit: The limit of the lower adjacent channel. Range: 0 dB to 100 dB, Unit: dB
			:param upper_limit: The limit of the upper adjacent channel. Range: 0 dB to 100 dB, Unit: dB
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('lower_limit', lower_limit, DataType.Float), ArgSingle('upper_limit', upper_limit, DataType.Float, None, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:ACHannel:RELative {param}'.rstrip())

	# noinspection PyTypeChecker
	class RelativeStruct(StructBase):
		"""Response structure. Fields: \n
			- Lower_Limit: float: The limit of the lower adjacent channel. Range: 0 dB to 100 dB, Unit: dB
			- Upper_Limit: float: The limit of the upper adjacent channel. Range: 0 dB to 100 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower_Limit'),
			ArgStruct.scalar_float('Upper_Limit')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower_Limit: float = None
			self.Upper_Limit: float = None

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> RelativeStruct:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:ACHannel[:RELative] \n
		Snippet: value: RelativeStruct = driver.calculate.limit.acPower.achannel.relative.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command defines the relative limit of the adjacent channels. The reference value for the relative limit is the
		measured channel power. If you have defined an absolute limit as well as a relative limit, the R&S FSW uses the lower
		value for the limit check. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: structure: for return value, see the help for RelativeStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:ACHannel:RELative?', self.__class__.RelativeStruct())

	def clone(self) -> 'RelativeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RelativeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MinimumCls:
	"""Minimum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("minimum", core, parent)

	def get(self, query_range: enums.SelectionRangeB) -> float:
		"""SCPI: [SENSe]:CHIRp:TIMing:BEGin:MINimum \n
		Snippet: value: float = driver.applications.k60Transient.sense.chirp.timing.begin.minimum.get(query_range = enums.SelectionRangeB.ALL) \n
		Returns the statistical value for the chirp begin from the statistics table for the specified chirp(s) . \n
			:param query_range: CURRent | ALL CURRent Detected chirps in the current capture buffer ALL All chirps detected in the entire measurement
			:return: result: CURRent | ALL CURRent Detected chirps in the current capture buffer ALL All chirps detected in the entire measurement"""
		param = Conversions.enum_scalar_to_str(query_range, enums.SelectionRangeB)
		response = self._core.io.query_str(f'SENSe:CHIRp:TIMing:BEGin:MINimum? {param}')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ACls:
	"""A commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("a", core, parent)

	def set(self, conversion_factor: float) -> None:
		"""SCPI: TRACe:IQ:APCon:A \n
		Snippet: driver.applications.iqAnalyzer.trace.iq.apcon.a.set(conversion_factor = 1.0) \n
		Defines the conversion factor A for the calculation of the average power consumption. For details see 'Average power
		consumption'. \n
			:param conversion_factor: numeric value
		"""
		param = Conversions.decimal_value_to_str(conversion_factor)
		self._core.io.write(f'TRACe:IQ:APCon:A {param}')

	def get(self) -> float:
		"""SCPI: TRACe:IQ:APCon:A \n
		Snippet: value: float = driver.applications.iqAnalyzer.trace.iq.apcon.a.get() \n
		Defines the conversion factor A for the calculation of the average power consumption. For details see 'Average power
		consumption'. \n
			:return: conversion_factor: No help available"""
		response = self._core.io.query_str(f'TRACe:IQ:APCon:A?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TextCls:
	"""Text commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("text", core, parent)

	def set(self, text: str) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:TEXT \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.text.set(text = '1') \n
		This command defines a text to explain the pattern. The text is displayed only in the selection menu (manual control) .
		This text should be short and concise. Detailed information about the pattern is given in the comment (see
		[SENSe:]DDEMod:SEARch:SYNC:COMMent) . \n
			:param text: No help available
		"""
		param = Conversions.value_to_quoted_str(text)
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:TEXT {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:TEXT \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.search.sync.text.get() \n
		This command defines a text to explain the pattern. The text is displayed only in the selection menu (manual control) .
		This text should be short and concise. Detailed information about the pattern is given in the comment (see
		[SENSe:]DDEMod:SEARch:SYNC:COMMent) . \n
			:return: text: No help available"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:SYNC:TEXT?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:FREQuency:CENTer:STEP:AUTO \n
		Snippet: driver.applications.k70Vsa.sense.frequency.center.step.auto.set(state = False) \n
		Defines the step width of the center frequency. \n
			:param state: ON | 1 Links the step width to the current standard (currently 1 MHz for all standards) OFF | 0 Sets the step width as defined using the FREQ:CENT:STEP command (see [SENSe:]FREQuency:CENTer:STEP) .
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:FREQuency:CENTer:STEP:AUTO {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:FREQuency:CENTer:STEP:AUTO \n
		Snippet: value: bool = driver.applications.k70Vsa.sense.frequency.center.step.auto.get() \n
		Defines the step width of the center frequency. \n
			:return: state: ON | 1 Links the step width to the current standard (currently 1 MHz for all standards) OFF | 0 Sets the step width as defined using the FREQ:CENT:STEP command (see [SENSe:]FREQuency:CENTer:STEP) ."""
		response = self._core.io.query_str(f'SENSe:FREQuency:CENTer:STEP:AUTO?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PtransistionCls:
	"""Ptransistion commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ptransistion", core, parent)

	def set(self, summary_bit: int, channel_name: str = None) -> None:
		"""SCPI: STATus:OPERation:PCALibration:PTRansistion \n
		Snippet: driver.status.operation.pcalibration.ptransistion.set(summary_bit = 1, channel_name = '1') \n
		No command help available \n
			:param summary_bit: No help available
			:param channel_name: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('summary_bit', summary_bit, DataType.Integer), ArgSingle('channel_name', channel_name, DataType.String, None, is_optional=True))
		self._core.io.write(f'STATus:OPERation:PCALibration:PTRansistion {param}'.rstrip())

	# noinspection PyTypeChecker
	class PtransistionStruct(StructBase):
		"""Response structure. Fields: \n
			- Summary_Bit: int: No parameter help available
			- Channel_Name: str: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Summary_Bit'),
			ArgStruct.scalar_str('Channel_Name')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Summary_Bit: int = None
			self.Channel_Name: str = None

	def get(self) -> PtransistionStruct:
		"""SCPI: STATus:OPERation:PCALibration:PTRansistion \n
		Snippet: value: PtransistionStruct = driver.status.operation.pcalibration.ptransistion.get() \n
		No command help available \n
			:return: structure: for return value, see the help for PtransistionStruct structure arguments."""
		return self._core.io.query_struct(f'STATus:OPERation:PCALibration:PTRansistion?', self.__class__.PtransistionStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def set(self, yaxis: enums.AxisHopTiming, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TRENd:HOP:TIMing:Y \n
		Snippet: driver.applications.k60Transient.calculate.trend.hop.timing.y.set(yaxis = enums.AxisHopTiming.BEGin, window = repcap.Window.Default) \n
		Configures the y-axis of the Parameter Trend result display for hop timing parameters. \n
			:param yaxis: BEGin | DWELl | SWITching BEGin Hop Begin DWELl Hop dwell time SWITching Switching time
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(yaxis, enums.AxisHopTiming)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRENd:HOP:TIMing:Y {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PreSelectionCls:
	"""PreSelection commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("preSelection", core, parent)

	def set(self) -> None:
		"""SCPI: CALibration:PRESelection \n
		Snippet: driver.calibration.preSelection.set() \n
		Due to changes in temperature, the YIG-preselector frequency may become slightly offset. This command re-aligns the
		preselector quickly, without requiring a full self-alignment of the R&S FSW. For R&S FSW85 models, the YIG2 filter is
		also re-aligned. This command is only available for R&S FSW models 1331.5003Kxx, and only if a YIG-preselector is
		available. \n
		"""
		self._core.io.write(f'CALibration:PRESelection')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CALibration:PRESelection \n
		Snippet: driver.calibration.preSelection.set_with_opc() \n
		Due to changes in temperature, the YIG-preselector frequency may become slightly offset. This command re-aligns the
		preselector quickly, without requiring a full self-alignment of the R&S FSW. For R&S FSW85 models, the YIG2 filter is
		also re-aligned. This command is only available for R&S FSW models 1331.5003Kxx, and only if a YIG-preselector is
		available. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALibration:PRESelection', opc_timeout_ms)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	def set(self, time: float) -> None:
		"""SCPI: [SENSe]:SWEep:SCAPture:LENGth[:TIME] \n
		Snippet: driver.applications.k6Pulse.sense.sweep.scapture.length.time.set(time = 1.0) \n
		Defines a time period (starting from the trigger offset) in which data is captured. If multiple events occur within one
		segment length, the segment is extended (see 'Number of events vs number of segments') . \n
			:param time: Unit: s
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SENSe:SWEep:SCAPture:LENGth:TIME {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:SCAPture:LENGth[:TIME] \n
		Snippet: value: float = driver.applications.k6Pulse.sense.sweep.scapture.length.time.get() \n
		Defines a time period (starting from the trigger offset) in which data is captured. If multiple events occur within one
		segment length, the segment is extended (see 'Number of events vs number of segments') . \n
			:return: time: Unit: s"""
		response = self._core.io.query_str(f'SENSe:SWEep:SCAPture:LENGth:TIME?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MeasurementCls:
	"""Measurement commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("measurement", core, parent)

	def set(self, meas_type: enums.RealtimeMeasType) -> None:
		"""SCPI: CONFigure:REALtime:MEASurement \n
		Snippet: driver.configure.realtime.measurement.set(meas_type = enums.RealtimeMeasType.HRESolution) \n
		In order to accommodate for different requirements, different measurement types are provided for Real-Time Spectrum
		measurements. These measurements are only available for R&S FSW-K161R. For R&S FSW-B512R/-B800R, the R&S FSW Real-Time
		Spectrum application always performs a 'Multi domain Real-Time Spectrum measurement'. In this case, this command is not
		available. \n
			:param meas_type: HRESolution High Resolution Real-Time measurements are performed with frequency spans of up to 160 MHz, allowing for very precise results in the frequency domain. Additional Span/RBW couplings are available for precise frequency results. Time domain evaluation is not available. MDOMain Multi Domain Real-Time measurements allow for results both in the frequency and time domains, however with spans up to 100 MHz only.
		"""
		param = Conversions.enum_scalar_to_str(meas_type, enums.RealtimeMeasType)
		self._core.io.write(f'CONFigure:REALtime:MEASurement {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.RealtimeMeasType:
		"""SCPI: CONFigure:REALtime:MEASurement \n
		Snippet: value: enums.RealtimeMeasType = driver.configure.realtime.measurement.get() \n
		In order to accommodate for different requirements, different measurement types are provided for Real-Time Spectrum
		measurements. These measurements are only available for R&S FSW-K161R. For R&S FSW-B512R/-B800R, the R&S FSW Real-Time
		Spectrum application always performs a 'Multi domain Real-Time Spectrum measurement'. In this case, this command is not
		available. \n
			:return: meas_type: HRESolution High Resolution Real-Time measurements are performed with frequency spans of up to 160 MHz, allowing for very precise results in the frequency domain. Additional Span/RBW couplings are available for precise frequency results. Time domain evaluation is not available. MDOMain Multi Domain Real-Time measurements allow for results both in the frequency and time domains, however with spans up to 100 MHz only."""
		response = self._core.io.query_str(f'CONFigure:REALtime:MEASurement?')
		return Conversions.str_to_scalar_enum(response, enums.RealtimeMeasType)
